@@ -13,13 +13,16 @@
 #   limitations under the License.
 
 import logging
+import os
+import sys
 from pathlib import Path
 from types import FunctionType
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Dict, Union
 
 import typer
 
 from dbgen.cli.styles import LOGO_STYLE, bad_typer_print
+from dbgen.configuration import update_config
 from dbgen.core.model import Model
 
 if TYPE_CHECKING:
@@ -27,15 +30,17 @@ if TYPE_CHECKING:
 
 # Errors
 ERROR_FORMAT = "Model is not in MODULE:PACKAGE format: {0}"
+ERROR_DEFAULT_MODEL = "Could not find model at model.main:make_model.\nThis is the default --model value, did you forget to set --model?"
 ERROR_MODULE = "Could not find module:\nModule: {0}\nPackage: {1}\nError: {2}"
 ERROR_PACKAGE = "Could not find package within module:\nModule: {0}\nPackage: {1}\nError: {2}"
+ERROR_ATTR = "Could not find Attribute within package:\nModule: {0}\nPackage: {1}\nError: {2}"
 ERROR_NOT_MODEL = "Import String is not for a DBgen Model: \nImport String: {0}\nClass: {1}"
 ERROR_NOT_MODEL_FUNCTION = "Import String is for a function that does not produce a DBgen Model: \nImport String: {0}\nOutput Class: {1}"
 ERROR_RUNNING_MODEL_FACT = "Import String is for a function produced an error or required arguments: \nImport String: {0}\nOutput Class: {1} \n{2}{3}"
 
 logger = logging.getLogger(__name__)
 
-state = {"confirm": True}
+state: Dict[str, Union[bool, Path, None]] = {"confirm": True, 'verbose': True, 'old_cwd': None}
 
 
 # Callback functions for parsing and validating args
@@ -58,6 +63,11 @@ def set_confirm(value: bool):
     state["confirm"] = not value
 
 
+def set_verbosity(verbose: bool):
+    """Auto confirm all prompted values"""
+    state["verbose"] = not verbose
+
+
 def file_existence(value: Path):
     if value and value.exists():
         return value
@@ -95,7 +105,11 @@ def validate_model_str(model_str: str) -> Model:
     Returns:
         Model: the output model after checks are in place
     """
-    basic_error = lambda fmt, val: typer.BadParameter(fmt.format(*val))
+    # Add current workind directory to the path at the end
+    cwd = os.getcwd()
+    sys.path.insert(0, cwd)
+
+    basic_error = lambda fmt, val: typer.BadParameter(fmt.format(*val), param_hint='--model')
 
     if model_str is None:
         raise typer.BadParameter("--model is required.")
@@ -125,13 +139,19 @@ def validate_model_str(model_str: str) -> Model:
                     ERROR_RUNNING_MODEL_FACT, [model_str, type(model).__name__, "#" * 24 + "\n", str(exc_str)]
                 ) from exc
             if isinstance(model, Model):
+                sys.path.remove(cwd)
                 return model
             raise basic_error(ERROR_NOT_MODEL_FUNCTION, [model_str, type(model).__name__])
 
         raise basic_error(ERROR_NOT_MODEL, [model_str, type(model).__name__])
-    except ModuleNotFoundError as exc:
+    except (ModuleNotFoundError, AttributeError) as exc:
+        if model_str == 'model.main:make_model':
+            raise basic_error(ERROR_DEFAULT_MODEL, []) from exc
+
         if "No module" in str(exc):
             raise basic_error(ERROR_MODULE, [module, package, str(exc)]) from exc
+        if isinstance(exc, AttributeError):
+            raise basic_error(ERROR_ATTR, [module, package, str(exc)]) from exc
         raise basic_error(ERROR_PACKAGE, [module, package, str(exc)]) from exc
 
 
@@ -142,3 +162,17 @@ def test_connection(conn: 'Connection', name: str = ''):
     if not conn.test():
         bad_typer_print(CONNECT_ERROR.format(name='meta', url=conn.url()))
         raise typer.Exit(code=2)
+
+
+def chdir_callback(directory: Path):
+    if directory:
+        state['old_cwd'] = directory.cwd()
+        os.chdir(directory)
+
+
+def config_callback(config_file: Path):
+    if config_file.exists():
+        update_config(config_file)
+    elif str(config_file.name) != '.env':
+        raise typer.BadParameter(f'Config file \'{config_file}\' does not exist')
+    return config_file
