@@ -43,7 +43,7 @@ from pydasher import hasher
 from pydasher.import_module import import_string
 
 from dbgen.configuration import ValidationEnum, config
-from dbgen.core.args import Arg, Const
+from dbgen.core.args import Arg, Constant
 from dbgen.core.base import Base
 from dbgen.core.dependency import Dependency
 from dbgen.core.node.computational_node import ComputationalNode
@@ -118,7 +118,7 @@ class LoadEntity(Base):
             # if we still have sub-errors raise the errors to the user
             if sub_errors:
                 raise errors
-        base_fields = {'id', 'gen_id', 'created_at'}
+        base_fields = {'id', 'etl_step_id', 'created_at'}
         return {
             k: v
             for k, v in validated_data.items()
@@ -194,7 +194,7 @@ T = TypeVar('T')
 
 class Load(ComputationalNode[T]):
     load_entity: LoadEntity
-    primary_key: Optional[Union[Arg, Const]] = None
+    primary_key: Optional[Union[Arg, Constant]] = None
     _output: Dict[UUID, Iterable[Any]] = PrivateAttr(default_factory=dict)
     insert: bool = False
     validation: Optional[ValidationEnum] = None
@@ -221,7 +221,7 @@ class Load(ComputationalNode[T]):
 
     @validator("primary_key")
     def check_const_primary_key(cls, primary_key):
-        if isinstance(primary_key, Const):
+        if isinstance(primary_key, Constant):
             assert (
                 primary_key.val is None
             ), f"Currently don't allow const primary keys to be used unless None is the value: {primary_key}"
@@ -235,7 +235,7 @@ class Load(ComputationalNode[T]):
         pk = values.get("primary_key")
         if load_entity is None:
             raise ValueError("Missing load_entity")
-        pk_is_missing = pk is None or (isinstance(pk, Const) and pk.val is None)
+        pk_is_missing = pk is None or (isinstance(pk, Constant) and pk.val is None)
         if insert or pk_is_missing:
             missing_attrs = filter(lambda x: x not in inputs, load_entity.identifying_attributes)
             missing_fks = filter(lambda x: x not in inputs, load_entity.identifying_foreign_keys)
@@ -277,6 +277,83 @@ class Load(ComputationalNode[T]):
             tables_needed=tables_needed,
         )
 
+    def new_run(
+        self, row: Dict[str, Mapping[str, Any]], rows_to_load: Dict[str, Dict[UUID, Any]]
+    ) -> Dict[str, List[UUID]]:
+        not_list = lambda x: not isinstance(x, (list, tuple))
+        lists_allowed = lambda x: self.load_entity.attributes[x].endswith('[]')
+        arg_dict = {
+            key: [val] if not_list(val) or lists_allowed(key) else val
+            for key, val in sorted(self._get_inputs(row).items())
+        }
+        # Check for empty lists, as that will cause the row to be ignored
+        if any(map(lambda x: len(x) == 0, arg_dict.values())):
+            # self._logger.debug(f'Row {arg_dict} produced 0 rows for load {self}')
+            return {self.outputs[0]: []}
+        # Check for broadcastability
+        try:
+            is_broadcastable(*arg_dict.values())
+        except ValueError as exc:
+            raise ValueError(
+                f"While assembling rows for loading into {self} found two sequences in the inputs to the load with non-equal, >1 length\n"
+                "This can occur when two outputs from pyblocks/queries are unequal in length.\n"
+                "If so, please make the relevant cartesian product of the two lists before loading\n"
+            ) from exc
+        try:
+            broadcasted_values = [
+                {key: val for key, val in zip(arg_dict.keys(), row)} for row in broadcast(*arg_dict.values())
+            ]
+        except ValueError as exc:
+            raise ValueError(
+                f"Error occurred during the loading of row {(str(arg_dict)[:100])} into entity {self.load_entity.full_name}"
+            ) from exc
+
+        # Load
+        validation = self.validation or config.validation
+        if validation == ValidationEnum.STRICT:
+            validation_func = self.load_entity._strict_validate
+        elif validation == ValidationEnum.COERCE:
+            validation_func = self.load_entity._validate
+
+        try:
+            broadcasted_values = list(map(partial(validation_func, insert=self.insert), broadcasted_values))
+        except PydValidationError as exc:
+            raise ValidationError(
+                f"Error occurred during data validation while loading into {self.load_entity.full_name!r}:\n{exc}"
+            ) from exc
+        # If we have a user supplied Primary Key go get it and broadcast it
+        if self.primary_key is not None:
+            primary_arg_val = self.primary_key.arg_get(row)
+            # Validate the primary key type
+            if isinstance(primary_arg_val, UUID):
+                primary_keys: List[UUID] = [primary_arg_val]
+            elif isinstance(primary_arg_val, Sequence):
+                assert all(map(lambda x: isinstance(x, UUID), primary_arg_val))
+                primary_keys = list(primary_arg_val)
+            else:
+                ValueError(f"Unknown Primary Key Type: {primary_arg_val}")
+
+            if len(primary_keys) == 1:
+                primary_keys *= len(broadcasted_values)
+            elif len(primary_keys) != len(broadcasted_values):
+                raise ValueError(
+                    f"Cannot broadcast Primary Key to Max Length: {len(primary_keys)} {len(broadcasted_values)}"
+                )
+        else:
+            # If we don't have a primary key get it from the identifying info on the broadcasted
+            # Values
+            primary_keys = [self.load_entity._get_hash(row) for row in broadcasted_values]
+        sorted_keys = sorted(self.inputs.keys())
+        # Update rows to load dict in place
+        rows_to_load[self.hash].update(
+            {
+                primary_key: [value[key] for key in sorted_keys]
+                for primary_key, value in zip(primary_keys, broadcasted_values)
+            }
+        )
+
+        return {self.outputs[0]: primary_keys}
+
     def run(self, row: Dict[str, Mapping[str, Any]]) -> Dict[str, List[UUID]]:
         not_list = lambda x: not isinstance(x, (list, tuple))
         lists_allowed = lambda x: self.load_entity.attributes[x].endswith('[]')
@@ -350,21 +427,21 @@ class Load(ComputationalNode[T]):
         )
         return {self.outputs[0]: primary_keys}
 
-    def load(self, cxn: connection, gen_id: UUID):
+    def load(self, cxn: connection, etl_step_id: UUID):
         """Run the Load statement for the given namespace rows.
 
         Args:
             namespace_rows (List[Dict[str, Any]]): A dictionary with the strings as hashes and the values as the local namespace dictionaries from PyBlocks, Queries, and Consts
         """
         self._logger.debug(f"Loading into {self.load_entity.name}")
-        self._load_data(cxn=cxn, gen_id=gen_id)
+        self._load_data(data=self._output, connection=cxn, etl_step_id=etl_step_id)
         self._output = {}
 
     def _get_types(self):
         oids = list(map(lambda x: self.load_entity.attributes[x], sorted(self.inputs.keys())))
         return oids
 
-    def _load_data(self, cxn: PG3Conn, gen_id: UUID) -> None:
+    def _load_data(self, data, connection: PG3Conn, etl_step_id: UUID) -> None:
         # Temporary table to copy data into
         # Set name to be hash of input rows to ensure uniqueness for parallelization
         temp_table_name = self.load_entity.name + "_temp_load_table_" + self.hash
@@ -380,17 +457,17 @@ class Load(ComputationalNode[T]):
         ALTER TABLE {temp_table_name}
         ADD COLUMN auto_inc SERIAL NOT NULL;
         ALTER TABLE {temp_table_name}
-        ALTER COLUMN "gen_id" SET DEFAULT '{gen_id}';
+        ALTER COLUMN "etl_step_id" SET DEFAULT '{etl_step_id}';
         """.format(
             obj=self.load_entity.name,
             schema=self.load_entity.schema_,
             temp_table_name=temp_table_name,
-            gen_id=gen_id,
+            etl_step_id=etl_step_id,
         )
-        with cxn.cursor() as cur:
+        with connection.cursor() as cur:
             cur.execute(drop_temp_table)
             cur.execute(create_temp_table)
-        cxn.commit()
+        connection.commit()
 
         cols = [self.load_entity.primary_key_name] + list(sorted(self.inputs.keys()))
         col_str = ','.join(map(lambda x: f"\"{x}\"", cols))
@@ -407,18 +484,18 @@ class Load(ComputationalNode[T]):
             obj=self.load_entity.name,
             obj_pk_name=self.load_entity.primary_key_name,
             temp_table_name=temp_table_name,
-            all_column_names=cols + ["gen_id"],
+            all_column_names=cols + ["etl_step_id"],
             first=first,
             update=update,
             schema=self.load_entity.schema_,
         )
         load_statement = template.render(**template_args)
-        with cxn.cursor() as cur:
+        with connection.cursor() as cur:
             self._logger.debug("load into temporary table")
             with cur.copy(f'COPY  {temp_table_name} ({col_str}) FROM STDIN') as copy:
                 oids = self._get_types()
                 copy.set_types(oids)
-                for pk_curr, row_curr in self._output.items():
+                for pk_curr, row_curr in data.items():
                     copy.write_row((pk_curr, *row_curr))
 
             # Try to insert everything from the temp table into the real table
@@ -455,5 +532,5 @@ class Load(ComputationalNode[T]):
                 self._logger.error(f"Fail count = {fk_fail_count}")
             self._logger.debug("Dropping temp table...")
             cur.execute(drop_temp_table)
-        cxn.commit()
+        connection.commit()
         self._logger.debug("loading finished")
